Welcome to Django Building Blocks’s documentation! — Django Building Blocks documentation

# Welcome to Django Building Blocks’s documentation!

Abstract Django base models to act as building blocks for rapid development of Django database models

# Getting Started

Install:

    pip install django-building-blocks

Contents:

- Models
  - Models
  - Mixins
  - Base
  - QuerySets
  - Interfaces
  - Blocks
- Admin
  - Admin blocks
  - Admin for Abstracts
  - Base
  - Mixins
  - Models
  - Utils
- Consts
  - Field names
- Rest
  - Serializers
- Contrib
  - Admin
  - Models

# Indices and tables

- Index

- Module Index

- Search Page